/***************************************************************************
 *   Copyright (C) 2004-2005 by Andrew Krause                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "browserfiles.h"

// Default constructor for the BrowserFiles class. This declares the TreeView
// object & then adds it to the scrolled window. It also makes sure that the
// header for the TreeView is not visible
BrowserFiles::BrowserFiles()
{
  treeview = new Gtk::TreeView();
  treeview->set_headers_visible(false);
  
  add(*treeview);
  set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS);
}

// Add the project files to the Gtk::TreeView. This function receives a
// pointer to an instance of the project settings class.
void BrowserFiles::populate_treeview(ProjectSettings *project)
{
  int start=0;
  Glib::ustring text = project->get_source_files(), file;
  Gtk::TreeModel::Row child;
  treeview->remove_all_columns();
  
  // Create project files tree view
  Glib::RefPtr<Gtk::TreeStore> model;
  ModelFilesColumns columns;

  // Create the Tree model:
  model = Gtk::TreeStore::create(columns);
  treeview->set_model(model);

  // Fill the TreeView's model
  Gtk::TreeModel::Row row_sources = *(model->append());
  row_sources[columns.col_text] = "Sources";
  Gtk::TreeModel::Row row_headers = *(model->append());
  row_headers[columns.col_text] = "Headers";
  Gtk::TreeModel::Row row_others = *(model->append());
  row_others[columns.col_text] = "Other Files";

  // Add the TreeView's view columns:
  treeview->append_column("Project Files", columns.col_text);

  // Append the sources
  for (unsigned int i=0; i<text.length(); i++)
  {
    if (text[i] == '/') 
    {
      child = *(model->append(row_sources.children()));
      child[columns.col_text] = text.substr(start, i-start);
      start = i+1;
    }
  }
  
  // Append the header files
  start=0;
  text = project->get_header_files();
  for (unsigned int i=0; i<text.length(); i++)
  {
    if (text[i] == '/') 
    {
      child = *(model->append(row_headers.children()));
      child[columns.col_text] = text.substr(start, i-start);
      start = i+1;
    }
  }
  
  // Append the other files
  start=0;
  text = project->get_other_files();
  for (unsigned int i=0; i<text.length(); i++)
  {
    if (text[i] == '/') 
    {
      child = *(model->append(row_others.children()));
      child[columns.col_text] = text.substr(start, i-start);
      start = i+1;
    }
  }
  
  // Expand all of the tree to show files
  treeview->expand_all();
  treeview->get_selection()->select(treeview->get_model()->get_iter("0"));
}

// Get the Gtk::TreeView object of the project file browser.
Gtk::TreeView* BrowserFiles::get_treeview()
{ return treeview;
}
