/***************************************************************************
 *   Copyright (C) 2004-2005 by Andrew Krause                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef PROJECT_PROPERTIES_H
#define PROJECT_PROPERTIES_H

#include "project.h"

#include <gtkmm/button.h>
#include <gtkmm/buttonbox.h>
#include <gtkmm/comboboxentry.h>
#include <gtkmm/entry.h>
#include <gtkmm/label.h>
#include <gtkmm/liststore.h>
#include <gtkmm/notebook.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/treeview.h>
#include <libglademm/xml.h>

// Class to add column to a TreeView (TreeModel)
class ModelColumnsCommands : public Gtk::TreeModel::ColumnRecord
{
public:
  ModelColumnsCommands()  {  add(col_command);  add(col_description); }
  Gtk::TreeModelColumn<Glib::ustring> col_command, col_description;
};

// Project Properties dialog class
class ProjectPropertiesDialog
{
public:
  ProjectPropertiesDialog (ProjectSettings*);
  ~ProjectPropertiesDialog();

  Gtk::Dialog* get_dialog();
  void initialize_objects();
  void populate_liststore();
  void add_row(Glib::ustring, Glib::ustring);
  void load_compiler_commands_from_makefile();
  void add_compiler_command(Glib::ustring);
  void on_add();

  Glib::ustring get_name();
  Glib::ustring get_author();
  Glib::ustring get_email();
  Glib::ustring get_homepage();
  Glib::ustring get_version();
  Glib::ustring get_commands();

private:
  Gtk::Dialog *dialog;
  Gtk::Button *cancel, *ok, *add;
  Gtk::Entry *name, *author, *email, *homepage, *version, *compiler;
  Gtk::TreeView *command_list;
  ModelColumnsCommands columns;
  Glib::RefPtr<Gtk::ListStore> model;
  Glib::ustring makefile_location;
};

#endif
